@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -265,7 +265,8 @@ return [
 					'select_var' => [
 						'' => lng('panel.none_value'),
 						'postfix' => 'postfix (smtp)',
-						'dovecot' => 'dovecot (imap/pop3)',
+						'dovecot' => 'dovecot <2.4 (imap/pop3)',
+						'dovecot24' => 'dovecot >=2.4 (imap/pop3)',
 						'proftpd' => 'proftpd (ftp)',
 					],
 					'save_method' => 'storeSettingFieldInsertUpdateServicesTask',
