@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -91,7 +91,7 @@ class SysLog extends ApiCommand implements ResourceEntity
 		Database::pexecute($result_stmt, $query_fields, true, true);
 		while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 			// clean log-text
-			$row['text'] = preg_replace("/[^\w @#\"':.()\[\]+\-_\/\\\!]/i", "_", $row['text']);
+			$row['text'] = preg_replace("/[^\w @#\"':.,()\[\]+\-_\/\\\!]/i", "_", $row['text']);
 			$result[] = $row;
 		}
 		$this->logger()->logAction($this->isAdmin() ? FroxlorLogger::ADM_ACTION : FroxlorLogger::USR_ACTION, LOG_INFO, "[API] list log-entries");
@@ -110,11 +110,12 @@ class SysLog extends ApiCommand implements ResourceEntity
 	 */
 	public function listingCount()
 	{
-		$params = null;
+		$params = [];
+		$query_fields = [];
 		if ($this->isAdmin() && $this->getUserDetail('customers_see_all') == '1') {
 			$result_stmt = Database::prepare("
 				SELECT COUNT(*) as num_logs FROM `" . TABLE_PANEL_LOG . "`
-			");
+			" . $this->getSearchWhere($query_fields));
 		} elseif ($this->isAdmin()) {
 			// get all admin customers
 			$_custom_list_result = $this->apiCall('Customers.listing');
@@ -127,12 +128,12 @@ class SysLog extends ApiCommand implements ResourceEntity
 				$result_stmt = Database::prepare("
 					SELECT COUNT(*) as num_logs FROM `" . TABLE_PANEL_LOG . "`
 					WHERE `user` = :loginname OR `user` IN ('" . implode("', '", $customer_names) . "')
-				");
+				" . $this->getSearchWhere($query_fields, true));
 			} else {
 				$result_stmt = Database::prepare("
 					SELECT COUNT(*) as num_logs FROM `" . TABLE_PANEL_LOG . "`
 					WHERE `user` = :loginname
-				");
+				" . $this->getSearchWhere($query_fields, true));
 			}
 			$params = [
 				'loginname' => $this->getUserDetail('loginname')
@@ -142,12 +143,12 @@ class SysLog extends ApiCommand implements ResourceEntity
 			$result_stmt = Database::prepare("
 				SELECT COUNT(*) as num_logs FROM `" . TABLE_PANEL_LOG . "`
 				WHERE `user` = :loginname AND `action` <> 99
-			");
+			" . $this->getSearchWhere($query_fields, true));
 			$params = [
 				'loginname' => $this->getUserDetail('loginname')
 			];
 		}
-
+		$params = array_merge($params, $query_fields);
 		$result = Database::pexecute_first($result_stmt, $params, true, true);
 		if ($result) {
 			return $this->response($result['num_logs']);
@@ -225,7 +226,7 @@ class SysLog extends ApiCommand implements ResourceEntity
 			}
 			$params['trunc'] = $truncatedate;
 			Database::pexecute($result_stmt, $params, true, true);
-			$this->logger()->logAction($this->isAdmin() ? FroxlorLogger::ADM_ACTION : FroxlorLogger::USR_ACTION, LOG_WARNING, "[API] truncated the froxlor syslog");
+			$this->logger()->logAction(FroxlorLogger::ADM_ACTION, LOG_WARNING, "[API] truncated the froxlor syslog");
 			return $this->response(true);
 		}
 		throw new Exception("Not allowed to execute given command.", 403);
